@@ -9,19 +9,19 @@
 // or else upgrading old project file will not work
 // reliably.
 // TODO QGIS 4: remove in favor of _QGIS_VERSION
-#define VERSION "3.44.2-Solothurn"
-#define _QGIS_VERSION "3.44.2-Solothurn"
+#define VERSION "3.44.3-Solothurn"
+#define _QGIS_VERSION "3.44.3-Solothurn"
 
 //used in vim src/core/qgis.cpp
 //The way below should work but it resolves to a number like 0110 which the compiler treats as octal I think
 //because debuggin it out shows the decimal number 72 which results in incorrect version status.
 //As a short term fix I (Tim) am defining the version in top level cmake. It would be good to
 //reinstate this more generic approach below at some point though
-//#define VERSION_INT 3442
+//#define VERSION_INT 3443
 // TODO QGIS 4: Remove in favor of _QGIS_VERSION_INT
-#define VERSION_INT 34402
-#define _QGIS_VERSION_INT 34402
-#define ABISYM(x) x ## 34402
+#define VERSION_INT 34403
+#define _QGIS_VERSION_INT 34403
+#define ABISYM(x) x ## 34403
 //used in main.cpp and anywhere else where the release name is needed
 #define RELEASE_NAME "Solothurn"
 
@@ -29,7 +29,7 @@
 #define QGIS_DATA_SUBDIR "share/qgis"
 #define QGIS_LIBEXEC_SUBDIR "lib/qgis"
 #define QGIS_LIB_SUBDIR "lib"
-#define QGIS_QML_SUBDIR "lib/qt/qml"
+#define QGIS_QML_SUBDIR "qml"
 
 #define QGIS_SERVER_MODULE_SUBDIR "lib/qgis/server"
 
@@ -42,18 +42,18 @@
 #define QGIS_MACAPP_BUNDLE 
 #endif
 
-#define PYTHON_VERSION "3.13.7"
+#define PYTHON_VERSION "3.11.13"
 #define PYTHON_VERSION_MAJOR "3"
-#define PYTHON_VERSION_MINOR "13"
-#define PYTHON_VERSION_PATCH "7"
+#define PYTHON_VERSION_MINOR "11"
+#define PYTHON_VERSION_PATCH "13"
 
 #define PROJ_VERSION_MAJOR 9
 #define PROJ_VERSION_MINOR 6
-#define PROJ_VERSION_PATCH 0
+#define PROJ_VERSION_PATCH 2
 
 /* #undef USING_NMAKE */
 
-#define USING_NINJA
+/* #undef USING_NINJA */
 
 #define HAVE_GUI
 
@@ -67,12 +67,12 @@
 
 /* #undef SERVER_SKIP_ECW */
 
-#define HAVE_SERVER_PYTHON_PLUGINS
+/* #undef HAVE_SERVER_PYTHON_PLUGINS */
 
 #define HAVE_OAUTH2_PLUGIN
 
-#define HAVE_OPENCL
-#define OPENCL_USE_NEW_HEADER
+/* #undef HAVE_OPENCL */
+/* #undef OPENCL_USE_NEW_HEADER */
 
 /* #undef ENABLE_MODELTEST */
 
@@ -88,7 +88,7 @@
 
 /* #undef AGGRESSIVE_SAFE_MODE */
 
-#define HAVE_QUICK
+/* #undef HAVE_QUICK */
 
 #define HAVE_QTSERIALPORT
 
@@ -102,21 +102,21 @@
 
 #define HAVE_COPC
 
-#define HAVE_PDAL_QGIS
-#define PDAL_VERSION "2.9.0"
-#define PDAL_VERSION_MAJOR_INT 2
-#define PDAL_VERSION_MINOR_INT 9
-#define PDAL_VERSION_MAJOR "2"
-#define PDAL_VERSION_MINOR "9"
-#define PDAL_VERSION_MICRO "0"
+/* #undef HAVE_PDAL_QGIS */
+#define PDAL_VERSION ""
+#define PDAL_VERSION_MAJOR_INT 
+#define PDAL_VERSION_MINOR_INT 
+#define PDAL_VERSION_MAJOR ""
+#define PDAL_VERSION_MINOR ""
+#define PDAL_VERSION_MICRO ""
 
-#define HAVE_DRACO
+/* #undef HAVE_DRACO */
 
-#define ENABLE_TESTS
+/* #undef ENABLE_TESTS */
 
-#define HAS_KDE_QT5_PDF_TRANSFORM_FIX
-#define HAS_KDE_QT5_SMALL_CAPS_FIX
-#define HAS_KDE_QT5_FONT_STRETCH_FIX
+/* #undef HAS_KDE_QT5_PDF_TRANSFORM_FIX */
+/* #undef HAS_KDE_QT5_SMALL_CAPS_FIX */
+/* #undef HAS_KDE_QT5_FONT_STRETCH_FIX */
 
 /* #undef HAVE_PDF4QT */
 
